# TEMA Visualizer

Library requires pandas version greater than 1.3

Install library using pip3 install tema-analyzer

Install with Jupyter Lab and Altair using pip3 install tema-analyzer[interactive]

Full documentation at https://tema-analyzer.readthedocs.io/en/latest/
